<?php

if (!defined('ABSPATH')) exit; // Exit if accessed directly

/**
 * Plugin Name: Универсальная интернет-касса Cash24
 * Plugin URI: http://cash24.ru
 * Description: Provides a Cash24 Payment Gateway.
 * Version: 1.0
 * Author: Cash24
 */


/* Add a custom payment class to WC
  ------------------------------------------------------------ */
add_action('plugins_loaded', 'woocommerce_cash24', 0);
function woocommerce_cash24()
{
	if (!class_exists('WC_Payment_Gateway'))
		return; // if the WC payment gateway class is not available, do nothing
	if (class_exists('WC_Cash24'))
		return;

	class WC_Cash24 extends WC_Payment_Gateway
	{
		public function __construct()
		{

			$plugin_dir = plugin_dir_url(__FILE__);

			global $woocommerce;

			$this->id = 'cash24';
			$this->method_title       = 'Универсальная интернет-касса Cash24';
			$this->icon = apply_filters('woocommerce_cash24_icon', '' . $plugin_dir . 'cash24.jpg');
			$this->has_fields = false;

			// Load the settings
			$this->init_form_fields();
			$this->init_settings();

			// Define user set variables
			$this->title = $this->get_option('title');
			$this->MNT_URL = $this->get_option('MNT_URL');
			$this->MNT_ID = $this->get_option('MNT_ID');
			$this->MNT_SECRET_KEY = $this->get_option('MNT_SECRET_KEY');
			$this->MNT_COMMAND_KEY = $this->get_option('MNT_COMMAND_KEY');
			$this->MNT_EXP = $this->get_option('MNT_EXP');
			$this->MNT_TEST_MODE = $this->get_option('MNT_TEST_MODE');
			$this->debug = $this->get_option('debug');
			$this->description = $this->get_option('description');
			$this->instructions = $this->get_option('instructions');

			// Logs
			if ($this->debug == 'yes') {
				$this->log = new WC_Logger();
			}

			// Actions
			add_action('woocommerce_receipt_cash24', array($this, 'receipt_page'));

			// Save options
			add_action('woocommerce_update_options_payment_gateways_cash24', array($this, 'process_admin_options'));

			// Payment listener/API hook
			add_action('woocommerce_api_wc_cash24', array($this, 'check_assistant_response'));

			if (!$this->is_valid_for_use()) {
				$this->enabled = false;
			}
		}

		/**
		 * Check if this gateway is enabled and available in the user's country
		 */
		function is_valid_for_use()
		{
			if (!in_array(get_option('woocommerce_currency'), array('RUB'))) {
				return false;
			}

			return true;
		}

		/**
		 * Admin Panel Options
		 * - Options for bits like 'title' and availability on a country-by-country basis
		 *
		 * @since 0.1
		 **/
		public function admin_options()
		{
			?>
			<h3><?php _e('Cash24', 'woocommerce'); ?></h3>
			<p><?php _e('Настройка приема электронных платежей через Cash24.', 'woocommerce'); ?></p>

			

			<table class="form-table">

				<?php
				// Generate the HTML For the settings form.
				$this->generate_settings_html();
				?>
			</table><!--/.form-table-->

		
		<?php
		

		} // End admin_options()

		/**
		 * Initialise Gateway Settings Form Fields
		 *
		 * @access public
		 * @return void
		 */
		function init_form_fields()
		{
			$this->form_fields = array(
				'enabled'                => array(
					'title'   => __('Включить/Выключить', 'woocommerce'),
					'type'    => 'checkbox',
					'label'   => __('Включен', 'woocommerce'),
					'default' => 'yes'
				),
				'title'                  => array(
					'title'       => __('Название', 'woocommerce'),
					'type'        => 'text',
					'description' => __('Это название, которое пользователь видит во время проверки.', 'woocommerce'),
					'default'     => __('Cash24', 'woocommerce')
				),
				'MNT_ID'                 => array(
					'title'       => __('Merchant ID', 'woocommerce'),
					'type'        => 'text',
					'description' => __('', 'woocommerce'),
					'default'     => ''
				),
				'MNT_SECRET_KEY' => array(
					'title'       => __('Secret Key', 'woocommerce'),
					'type'        => 'text',
					'description' => __('', 'woocommerce'),
					'default'     => ''
				),
				'MNT_COMMAND_KEY' => array(
					'title'       => __('Command Key', 'woocommerce'),
					'type'        => 'text',
					'description' => __('', 'woocommerce'),
					'default'     => ''
				),
				'MNT_EXP' => array(
					'title'       => __('Срок действия счета (суток)', 'woocommerce'),
					'type'        => 'text',
					'description' => __('', 'woocommerce'),
					'default'     => '3'
				),
				'MNT_TEST_MODE'          => array(
					'title'       => __('Тестовый режим', 'woocommerce'),
					'type'        => 'checkbox',
					'label'       => __('Включен', 'woocommerce'),
					'description' => __('', 'woocommerce'),
					'default'     => 'no'
				),
				'debug'                  => array(
					'title'   => __('Debug', 'woocommerce'),
					'type'    => 'checkbox',
					'label'   => __('Включить логирование (<code>woocommerce/logs/cash24.txt</code>)', 'woocommerce'),
					'default' => 'no'
				),
				'description'            => array(
					'title'       => __('Description', 'woocommerce'),
					'type'        => 'textarea',
					'description' => __('Описанием метода оплаты которое клиент будет видеть на вашем сайте.', 'woocommerce'),
					'default'     => 'Оплата с помощью cash24.'
				),
				'instructions'           => array(
					'title'       => __('Instructions', 'woocommerce'),
					'type'        => 'textarea',
					'description' => __('Инструкции, которые будут добавлены на страницу благодарностей.', 'woocommerce'),
					'default'     => 'Оплата с помощью cash24.'
				)
			);
		}

		/**
		 * Дополнительная информация в форме выбора способа оплаты
		 **/
		function payment_fields()
		{
			if ($this->description) {
				echo wpautop(wptexturize($this->description));
			}
		}

		/**
		 * Process the payment and return the result
		 **/
		function process_payment($order_id)
		{
			$order = new WC_Order($order_id);

			return array(
				'result'   => 'success',
				'redirect' => add_query_arg('order', $order->id, add_query_arg('key', $order->order_key, get_permalink(woocommerce_get_page_id('pay'))))
			);
		}

		/**
		 * Форма оплаты
		 **/
		function receipt_page($order_id)
		{
			

			$order = new WC_Order($order_id);
			$amount = number_format($order->order_total, 2, '.', '');
$time = time() + $this->MNT_EXP * 24 * 60 * 60;
  $exptime=gmdate('Y-m-d', $time) . 'T' . gmdate('H:i:s', $time);



$arParams = array();
$arParams['amount']=$amount;
$arParams['currency']='RUB';
$arParams['email']=$order->billing_email;
$arParams['description']='Order '.$order_id;
$arParams['order']=(int)$order_id;
$arParams['success']=htmlspecialchars('http://'.$_SERVER['SERVER_NAME'].'/?wc-api=wc_cash24&req=success');
$arParams['cancel']=htmlspecialchars('http://'.$_SERVER['SERVER_NAME'].'/?wc-api=wc_cash24&req=fail');
$arParams['callback']=htmlspecialchars('http://'.$_SERVER['SERVER_NAME'].'/?wc-api=wc_cash24&req=callback');
$arParams['method']='';
$arParams['phone']=$order->billing_phone;
$arParams['wallet']='';
$arParams['expires']=$exptime;

	
               
     
$headers = array(
    "Content-type: text/xml"
    
);
$k= $this->createInvoice($arParams,$this->MNT_ID,$this->MNT_COMMAND_KEY);

switch ($this->MNT_TEST_MODE) {
				case 'yes':
					$respurl="http://api.staging.cash24.ru/1.0/";
					break;
				case 'no':
					$respurl="https://api.cash24.ru/1.0/";
					break;
			}

   $curl = curl_init();
    curl_setopt($curl, CURLOPT_URL, $respurl);
    curl_setopt($curl, CURLOPT_RETURNTRANSFER,true);
    curl_setopt($curl, CURLOPT_POST, true);
    curl_setopt($curl, CURLOPT_POSTFIELDS, $k);
 curl_setopt($curl, CURLOPT_HTTPHEADER, $headers );
  
 curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, 0);
curl_setopt($curl, CURLOPT_SSL_VERIFYHOST, 0);
    $out = curl_exec($curl);
$url = simplexml_load_string($out);

$turl= $url;
 
  $url = $url->response->url; //формируем строку url

  if(!empty($turl->envelope->error)){
  
  
die($turl->envelope->text);
  
  }
 
		

            



			echo '<form id="cash24_form" action='.$url.' method="GET"></form><script type="text/javascript">document.getElementById("cash24_form").submit();</script>';
		}

		

		/**
		 * Check Response
		 **/
		function check_assistant_response()
		{
			global $woocommerce;

			$_REQUEST = stripslashes_deep($_REQUEST);
			if (isset($_REQUEST['req']) AND $_REQUEST['req'] == 'callback') {
				@ob_clean();
$request=$_POST;
$order_id=$request['order'];


if($request['status']=='20'){

$order = new WC_Order($order_id);
                $order = new WC_Order($order_id);
				$order->update_status('on-hold', __('Платеж успешно оплачен', 'woocommerce'));
				$woocommerce->cart->empty_cart();
	}
	if($request['status']=='30'){
	 $order = new WC_Order($order_id);
				$order->update_status('cancelled', __('Платеж отменен', 'woocommerce'));
				$woocommerce->cart->empty_cart();
				die();
	}
	if($request['status']=='40'){
		$order = new WC_Order($order_id);
	    $order->add_order_note(__('Платеж успешно завершен.', 'woocommerce'));
		$order->payment_complete();
		$woocommerce->cart->empty_cart();
	     die();
	}
	if($request['status']=='50'){
	    $order = new WC_Order($order_id);
				$order->update_status('cancelled', __('Платеж возвращен', 'woocommerce'));
				$woocommerce->cart->empty_cart();
				die();
	}

				
			} else if (isset($_REQUEST['req']) AND $_REQUEST['req'] == 'success') {
				$order = new WC_Order($_REQUEST['order']);
				
				$woocommerce->cart->empty_cart();

				wp_redirect($this->get_return_url($order));
				exit;
			} else if (isset($_REQUEST['req']) AND $_REQUEST['req'] == 'fail') {
				$order = new WC_Order($_REQUEST['order']);
				$woocommerce->cart->empty_cart();
				wp_redirect($order->get_cancel_order_url());
				exit;
			}

		}
function createInvoice($arParams,$auth,$key)
 {
  
  $request = '';
  $toSign = 'create-invoice';
  foreach ($arParams as $c => $val)
  {
   $request .= "<$c>" . $val . "</$c>\r\n";
   if ($c != 'expires' AND $c != 'phone')
    $toSign .= '-' . $val;
  }

  $sign = md5(htmlspecialchars_decode($toSign) . '-' . $key);

  $xml = '
   <?xml version="1.0" encoding="utf-8"?>
   <cash24 xmlns="http://api.cash24.ru/1.0/">
     <request xmlns="http://api.cash24.ru/1.0/create-invoice/">
    ' . $request . '
     </request>
     <envelope>
    <auth>' . $auth . '</auth>
    <sign>' . $sign . '</sign>
     </envelope>
   </cash24>
  ';

  return trim($xml);
 }
	}
 
	/**
	 * Add the gateway to WooCommerce
	 **/
	function add_cash24_gateway($methods)
	{
		$methods[] = 'WC_Cash24';

		return $methods;
	}

	add_filter('woocommerce_payment_gateways', 'add_cash24_gateway');
}

?>